==> v11.1.0.tar.gz: brewman/overlord/src/app/stock-movement/stock-movement-datasource.ts <==
import { DataSource } from '@angular/cdk/collections';
import { EventEmitter } from '@angular/core';
import { MatPaginator, PageEvent } from '@angular/material/paginator';
import { MatSort, Sort } from '@angular/material/sort';
import { merge, Observable, of as observableOf } from 'rxjs';
import { map } from 'rxjs/operators';

import { StockMovementItem } from './stock-movement-item';

/** Simple sort comparator for example ID/Name columns (for client-side sorting). */
const compare = (a: string | number, b: string | number, isAsc: boolean) =>
  (a < b ? -1 : 1) * (isAsc ? 1 : -1);
export class StockMovementDataSource extends DataSource<StockMovementItem> {
  constructor(
    public data: StockMovementItem[],
    private paginator?: MatPaginator,
    private sort?: MatSort,
  ) {
    super();
  }

  connect(): Observable<StockMovementItem[]> {
    const dataMutations: (
      | Observable<StockMovementItem[]>
      | EventEmitter<PageEvent>
      | EventEmitter<Sort>
    )[] = [observableOf(this.data)];
    if (this.paginator) {
      dataMutations.push((this.paginator as MatPaginator).page);
    }
    if (this.sort) {
      dataMutations.push((this.sort as MatSort).sortChange);
    }

    // Set the paginators length
    if (this.paginator) {
      this.paginator.length = this.data.length;
    }

    return merge(...dataMutations).pipe(
      map(() => this.getPagedData(this.getSortedData([...this.data]))),
    );
  }

  disconnect() {}

  private getPagedData(data: StockMovementItem[]) {
    if (this.paginator === undefined) {
      return data;
    }
    const startIndex = this.paginator.pageIndex * this.paginator.pageSize;
    return data.splice(startIndex, this.paginator.pageSize);
  }

  private getSortedData(data: StockMovementItem[]) {
    if (this.sort === undefined) {
      return data;
    }
    if (!this.sort.active || this.sort.direction === '') {
      return data;
    }

    const sort = this.sort as MatSort;
    return data.sort((a, b) => {
      const isAsc = sort.direction === 'asc';
      switch (sort.active) {
        case 'group':
          return compare(a.group, b.group, isAsc);
        case 'name':
          return compare(a.name, b.name, isAsc);
        case 'opening':
          return compare(+a.opening, +b.opening, isAsc);
        case 'purchase':
          return compare(+a.purchase, +b.purchase, isAsc);
        case 'issue':
          return compare(+a.issue, +b.issue, isAsc);
        case 'closing':
          return compare(+a.closing, +b.closing, isAsc);
        default:
          return 0;
      }
    });
  }
}

==> v11.1.2.tar.gz: brewman/overlord/src/app/stock-movement/stock-movement-datasource.ts <==
import { DataSource } from '@angular/cdk/collections';
import { EventEmitter } from '@angular/core';
import { MatPaginator, PageEvent } from '@angular/material/paginator';
import { MatSort, Sort } from '@angular/material/sort';
import { merge, Observable, of as observableOf } from 'rxjs';
import { map } from 'rxjs/operators';

import { StockMovementItem } from './stock-movement-item';

/** Simple sort comparator for example ID/Name columns (for client-side sorting). */
const compare = (a: string | number, b: string | number, isAsc: boolean) =>
  (a < b ? -1 : 1) * (isAsc ? 1 : -1);
export class StockMovementDataSource extends DataSource<StockMovementItem> {
  constructor(
    public data: StockMovementItem[],
    private paginator?: MatPaginator,
    private sort?: MatSort,
  ) {
    super();
  }

  connect(): Observable<StockMovementItem[]> {
    const dataMutations: (EventEmitter<PageEvent> | EventEmitter<Sort>)[] = [];
    if (this.paginator) {
      dataMutations.push((this.paginator as MatPaginator).page);
    }
    if (this.sort) {
      dataMutations.push((this.sort as MatSort).sortChange);
    }

    // Set the paginators length
    if (this.paginator) {
      this.paginator.length = this.data.length;
    }

    return merge(observableOf(this.data), ...dataMutations).pipe(
      map(() => this.getPagedData(this.getSortedData([...this.data]))),
    );
  }

  disconnect() {}

  private getPagedData(data: StockMovementItem[]) {
    if (this.paginator === undefined) {
      return data;
    }
    const startIndex = this.paginator.pageIndex * this.paginator.pageSize;
    return data.splice(startIndex, this.paginator.pageSize);
  }

  private getSortedData(data: StockMovementItem[]) {
    if (this.sort === undefined) {
      return data;
    }
    if (!this.sort.active || this.sort.direction === '') {
      return data;
    }

    const sort = this.sort as MatSort;
    return data.sort((a, b) => {
      const isAsc = sort.direction === 'asc';
      switch (sort.active) {
        case 'group':
          return compare(a.group, b.group, isAsc);
        case 'name':
          return compare(a.name, b.name, isAsc);
        case 'opening':
          return compare(+a.opening, +b.opening, isAsc);
        case 'purchase':
          return compare(+a.purchase, +b.purchase, isAsc);
        case 'issue':
          return compare(+a.issue, +b.issue, isAsc);
        case 'closing':
          return compare(+a.closing, +b.closing, isAsc);
        default:
          return 0;
      }
    });
  }
}
